@@ -18,7 +18,7 @@ from virtualenv.util.subprocess import Popen
 @pytest.mark.slow
 @pytest.mark.timeout(timeout=60)
 @pytest.mark.parametrize("copies", [False, True] if fs_supports_symlink() else [True])
-def test_base_bootstrap_link_via_app_data(tmp_path, coverage_env, current_fastest, copies):
+def test_seed_link_via_app_data(tmp_path, coverage_env, current_fastest, copies):
     current = PythonInfo.current_system()
     bundle_ver = BUNDLE_SUPPORT[current.version_release_str]
     create_cmd = [
@@ -56,6 +56,7 @@ def test_base_bootstrap_link_via_app_data(tmp_path, coverage_env, current_fastes
         for suffix in (
             "",
             "{}".format(current.version_info.major),
+            "{}.{}".format(current.version_info.major, current.version_info.minor),
             "-{}.{}".format(current.version_info.major, current.version_info.minor),
         )
     ]:
@@ -121,3 +122,14 @@ def test_base_bootstrap_link_via_app_data_not_writable(tmp_path, current_fastest
     dest = tmp_path / "venv"
     result = cli_run(["--seeder", "app-data", "--creator", current_fastest, "--clear-app-data", "-vv", str(dest)])
     assert result
+
+
+@pytest.mark.slow
+@pytest.mark.timeout(timeout=60)
+@pytest.mark.parametrize("pkg", ["pip", "setuptools", "wheel"])
+def test_base_bootstrap_link_via_app_data_no(tmp_path, coverage_env, current_fastest, session_app_data, pkg):
+    create_cmd = [str(tmp_path), "--seeder", "app-data", "--no-{}".format(pkg)]
+    result = cli_run(create_cmd)
+    assert not (result.creator.purelib / pkg).exists()
+    for key in {"pip", "setuptools", "wheel"} - {pkg}:
+        assert (result.creator.purelib / key).exists()
